==> guru-cli-0.1.4.tgz: package/README.md <==
# Guru CLI

[![GitHub Workflow Status](https://img.shields.io/github/workflow/status/pliancy/guru-cli/CI)](https://github.com/pliancy/timelyapp-sdk)
[![npm](https://img.shields.io/npm/v/guru-cli.svg)](https://www.npmjs.com/package/guru-cli)
[![Downloads](https://img.shields.io/npm/dm/guru-cli.svg)](https://www.npmjs.com/package/guru-cli)
[![Dependency Status](https://img.shields.io/david/pliancy/guru-cli)](https://david-dm.org/pliancy/guru-cli)
[![License](https://img.shields.io/github/license/pliancy/guru-cli)](https://www.npmjs.com/package/guru-cli)

A NodeJS based CLI tool for doing useful things against the Guru KB (https://getguru.com)

**_Note: This project is still a work in progress. It is currently in active development. Use at your own risk!_**

This tool was made for us at Pliancy to solve some problems we were commonly running into. We hope it's useful to others as well!

It currently provides the following features:

- Search all cards with a powerful query language supporting regex in the title, content, collection, and board metadata.
- Verify any card administratively by generating an API token for that owner of that card and using it to verify it (working around Guru's limitation of only assigned verifier being able to verify a card)
- Find and replace across all Guru cards with regex support, optional filtering, and powerful preview.
- Backup your guru cards to JSON format.

## Installation

The NPM method is preferred since it is consistent across operating systems. The homebrew method is for convienence only.

### NPM Method

Install Node JS 14 or greater if you do not already have it from the [Offical NodeJS Download Page](https://nodejs.org/en/download/)

```shell
npm install -g guru-cli

# or

yarn global add guru-cli
```

### Homebrew Method

```bash
brew install pliancy/tap/guru-cli
```

## Getting Started

1. First, you need to authenticate to guru API. Navigate to https://app.getguru.com/settings/api-access and generate an API token for a **Guru admin account**
2. Login to the cli tool

```bash
$ guru-cli login
Login to Guru API
-------------------
Guru Admin Email: example@company.com
Admin API Token: definitelymyapitokenpleasedontsteal
✅ Successfully authenticated to Guru API. You can now run guru-cli commands.
```

Now you're ready!

## The filter query language

Many commands support a powerful filtering syntax with regex support. The filtering supports a familiar google-style query syntax of `key:value` where key is one of `collection`, `board`, `title`, or `content` and value is any ECMAScript supported regular expression. Typically you can just fuzzy match via something like `title:Overview` which logically means title contains the substring "Overview". See below for more examples of using this filtering.

If you need to ignore case sensitivity in the supplied regex you can pass the `--ignore-case` or `-i` flag to the command.

## Examples

### Find all cards with the words "Typescript" or "Javascript" in the title under the "Engineering" collection

```bash
guru-cli find 'title:Typescript|Javascript collection:Engineering'
```

### Find cards that have the text "Caleb" and "great guy" with anything in between in the content

```bash
guru-cli find 'content:Caleb.*great guy'
```

### Verify all cards that are in expired state

```bash
guru-cli verify-expired
```

### Verify all cards that are in expired state in collection Engineering with "Overview" in title

```bash
guru-cli verify-expired 'collection:Engineering title:Overview'
```

### Find and replace across all cards

```bash
guru-cli find-replace 'G Suite' 'Google Workspace'
```

once you're confident in your changes affecting the proper data in the preview:

```bash
guru-cli find-replace 'G Suite' 'Google Workspace' --confirm
```

### Find and replace across cards except for the ones that have the phrase "this is how you get ants"

This one is a bit more complex because it uses a regex feature known as negitive look-ahead in the filter to accomplish filtering out the relevent cards

```bash
guru-cli find-replace 'Archer' 'Lana' 'content:"^(?!.*this is how you get ants)"'
```

once you're confident in your changes affecting the proper data in the preview:

```bash
guru-cli find-replace 'Archer' 'Lana' 'content:"^(?!.*this is how you get ants)"' --confirm
```

### Backup your Guru Cards to JSON

```bash
guru-cli backup-cards /path/to/some/folder
```

==> guru-cli-1.0.0.tgz: package/README.md <==
# Guru CLI

[![GitHub Workflow Status](https://img.shields.io/github/workflow/status/pliancy/guru-cli/CI)](https://github.com/pliancy/timelyapp-sdk)
[![npm](https://img.shields.io/npm/v/guru-cli.svg)](https://www.npmjs.com/package/guru-cli)
[![Downloads](https://img.shields.io/npm/dm/guru-cli.svg)](https://www.npmjs.com/package/guru-cli)
[![Dependency Status](https://img.shields.io/david/pliancy/guru-cli)](https://david-dm.org/pliancy/guru-cli)
[![License](https://img.shields.io/github/license/pliancy/guru-cli)](https://www.npmjs.com/package/guru-cli)

A NodeJS based CLI tool for doing useful things against the Guru KB (<https://getguru.com>)

**_Note: This project is still a work in progress. It is currently in active development. Use at your own risk!_**

This tool was made for us at Pliancy to solve some problems we were commonly running into. We hope it's useful to others as well!

It currently provides the following features:

- Search all cards with a powerful query language supporting regex in the title, content, collection, and board metadata.
- Verify any card administratively by generating an API token for that owner of that card and using it to verify it (working around Guru's limitation of only assigned verifier being able to verify a card)
- Find and replace across all Guru cards with regex support, optional filtering, and powerful preview.
- Backup your guru cards to JSON format.

## Installation

The NPM method is preferred since it is consistent across operating systems. The homebrew method is for convienence only.

### NPM Method

Install Node JS 14 or greater if you do not already have it from the [Offical NodeJS Download Page](https://nodejs.org/en/download/)

```shell
npm install -g guru-cli

# or

yarn global add guru-cli
```

### Homebrew Method

```bash
brew install pliancy/tap/guru-cli
```

## Getting Started

1. First, you need to authenticate to guru API. Navigate to <https://app.getguru.com/settings/api-access> and generate an API token for a **Guru admin account**
2. Login to the cli tool

```bash
$ guru-cli login
Login to Guru API
-------------------
Guru Admin Email: example@company.com
Admin API Token: definitelymyapitokenpleasedontsteal
✅ Successfully authenticated to Guru API. You can now run guru-cli commands.
```

Now you're ready!

## The filter query language

Many commands support a powerful filtering syntax with regex support. The filtering supports a familiar google-style query syntax of `key:value` where key is one of `collection`, `board`, `title`, or `content` and value is any ECMAScript supported regular expression. Typically you can just fuzzy match via something like `title:Overview` which logically means title contains the substring "Overview". See below for more examples of using this filtering.

If you need to ignore case sensitivity in the supplied regex you can pass the `--ignore-case` or `-i` flag to the command.

## Examples

### Find all cards with the words "Typescript" or "Javascript" in the title under the "Engineering" collection

```bash
guru-cli find 'title:Typescript|Javascript collection:Engineering'
```

### Find cards that have the text "Caleb" and "great guy" with anything in between in the content

```bash
guru-cli find 'content:Caleb.*great guy'
```

### Verify all cards that are in expired state

```bash
guru-cli verify-expired
```

### Verify all cards that are in expired state in collection Engineering with "Overview" in title

```bash
guru-cli verify-expired 'collection:Engineering title:Overview'
```

### Find and replace across all cards

```bash
guru-cli find-replace 'G Suite' 'Google Workspace'
```

once you're confident in your changes affecting the proper data in the preview:

```bash
guru-cli find-replace 'G Suite' 'Google Workspace' --confirm
```

### Find and replace across cards except for the ones that have the phrase "this is how you get ants"

This one is a bit more complex because it uses a regex feature known as negitive look-ahead in the filter to accomplish filtering out the relevent cards

```bash
guru-cli find-replace 'Archer' 'Lana' 'content:"^(?!.*this is how you get ants)"'
```

once you're confident in your changes affecting the proper data in the preview:

```bash
guru-cli find-replace 'Archer' 'Lana' 'content:"^(?!.*this is how you get ants)"' --confirm
```

### Backup your Guru Cards to JSON

```bash
guru-cli backup-cards /path/to/some/folder
```
